@@ -4,7 +4,7 @@ import json
 import logging
 import click
 import yaml
-import cisco
+from cli import *
 import pprint
 from pathlib import Path
 from gtts import gTTS
